@@ -143,6 +143,8 @@ EngineGraphQLGitHub <- R6::R6Class(
             NA
           }
           commit$node$committed_date <- gts_to_posixt(commit$node$committed_date)
+          commit$node$repo_url <- commit$node$repository$url
+          commit$node$repository <- NULL
           commit$node
         })
         commits_row$repository <- repo_name
@@ -159,6 +161,10 @@ EngineGraphQLGitHub <- R6::R6Class(
           dplyr::relocate(
             any_of(c("author_login", "author_name")),
             .after = author
+          ) %>%
+          dplyr::relocate(
+            repo_url,
+            .before = api_url
           )
       }
       return(commits_table)
@@ -386,18 +392,18 @@ EngineGraphQLGitHub <- R6::R6Class(
                                           repo,
                                           since,
                                           until,
-                                          commits_cursor = "",
-                                          author_id = "") {
-      commits_by_org_query <- self$gql_query$commits_by_repo(
-        org = org,
-        repo = repo,
-        since = date_to_gts(since),
-        until = date_to_gts(until),
-        commits_cursor = commits_cursor,
-        author_id = author_id
+                                          commits_cursor = "") {
+      commits_by_org_query <- self$gql_query$commits_from_repo(
+        commits_cursor = commits_cursor
       )
       response <- self$gql_response(
-        gql_query = commits_by_org_query
+        gql_query = commits_by_org_query,
+        vars = list(
+          "org" = org,
+          "repo" = repo,
+          "since" = date_to_gts(since),
+          "until" = date_to_gts(until)
+        )
       )
       return(response)
     },
